import sqlite3
from .base_manager import Data_Manager
from runflare.settings import USER_HOME_PATH,DATASTORE,FOLDER_NAME

import os

class Sqllite_Manager(Data_Manager):

    def __init__(self):
        self.DATASTORE_NAME = DATASTORE.get("NAME")
        self.DATASTORE_BACKEND = DATASTORE.get("BACKEND")
        assert self.DATASTORE_BACKEND == "sqlite3", "Invalid Backend"
        self.cursor = None
        self.main_db_path = str(USER_HOME_PATH) + f"/{FOLDER_NAME}/"
        self.db_name = f"{self.DATASTORE_NAME}"


    def create_connection(self,path,db_name):
        try:
            if not self.mkdirs(path):
                exit(1)
            conn = sqlite3.connect(path+db_name)
            return conn
        except sqlite3.Error as e:
            print(e)
            exit(1)

    def close_connection(self, connection):
        connection.commit()
        connection.close()


    def check_table_exists(self,conn,table_name):
        query = f"SELECT name FROM sqlite_master WHERE type='table' AND name='{table_name}';"
        cursor = conn.cursor()
        cursor.execute(query)
        result = cursor.fetchall()
        if not result:
            return False
        return True

    def create_table(self,conn,table_name,**fields):
        query = self.create_table_query(table_name,**fields)
        cursor = conn.cursor()
        cursor.execute(query)

    def insert_into(self,conn,table_name,**fields):
        query,params = self.insert_into_query(table_name, **fields)
        cursor = conn.cursor()
        cursor.execute(query, params)

    def drop_table(self,conn,table_name):
        query = self.drop_table_query(table_name)
        cursor = conn.cursor()
        cursor.execute(query)




    def save_token(self,token,email):
        self.conn = self.create_connection(self.main_db_path,self.db_name)
        self.cursor = self.conn.cursor()
        self.create_table(self.conn,"Token", token="VARCHAR(255)", email="VARCHAR(255)")
        self.insert_into(self.conn,"Token",token=token, email=email)
        self.close_connection(self.conn)

    def del_token(self):
        if os.path.exists(self.main_db_path+self.db_name):

            self.conn = self.create_connection(self.main_db_path, self.db_name)
            self.cursor = self.conn.cursor()

            if not self.check_table_exists(self.conn,"Token"):
                return False, "You'r Not logged in"
            self.drop_table(self.conn, "Token")
            self.close_connection(self.conn)
            return True, "Successfully Logged Out"
        else:
            return False, "You'r Not logged in"

    def get_token(self):
        if os.path.exists(self.main_db_path+self.db_name):
            self.conn = self.create_connection(self.main_db_path, self.db_name)
            self.cursor = self.conn.cursor()

            if not self.check_table_exists(self.conn, "Token"):
                return False, "You'r Not logged in"

            query = "SELECT * FROM Token WHERE id=(SELECT max(id) FROM Token);"
            self.cursor.execute(query)
            result = self.cursor.fetchall()
            self.close_connection(self.conn)
            if not result:
                return False,"Please Login First"
            return True,result[0][1]
        else:
            return False,"Please Login First"



    @property
    def get_project_root(self):
        current_path = os.getcwd()
        _,roots = self.get_project_roots
        for root in roots:
            if root[1] in current_path:
                return root[1]
        self.save_project_root(current_path)
        return current_path

    @property
    def get_project_roots(self):
        if os.path.exists(self.main_db_path + self.db_name):
            self.conn = self.create_connection(self.main_db_path, self.db_name)
            self.cursor = self.conn.cursor()

            if not self.check_table_exists(self.conn, "Roots"):
                return False, []
            query = "SELECT * FROM Roots;"
            self.cursor.execute(query)
            result = self.cursor.fetchall()
            self.close_connection(self.conn)
            return True, result
        else:
            return False, []

    def save_project_root(self,root):
        self.conn = self.create_connection(self.main_db_path, self.db_name)
        self.cursor = self.conn.cursor()
        self.create_table(self.conn, "Roots", root="VARCHAR(255)")
        self.insert_into(self.conn, "Roots",root=root)
        self.close_connection(self.conn)


    def get_project_cache(self,local_db_path):
        if os.path.exists(local_db_path + self.db_name):
            self.conn = self.create_connection(local_db_path, self.db_name)
            self.cursor = self.conn.cursor()

            if not self.check_table_exists(self.conn, "Cache"):
                return 0, []
            query = "SELECT project,project_id,item,item_id FROM Cache WHERE id=(SELECT max(id) FROM Cache);"
            self.cursor.execute(query)
            result = self.cursor.fetchall()
            result = result[0]
            if None in result[0:2]:
                return 0, []
            if None in result[2:4]:
                return 3, result[0:2]
            self.close_connection(self.conn)
            return True, result
        else:
            return 0, []

    def execute(self,conn,query):
        self.cursor = conn.cursor()
        self.cursor.execute(query)
        return self.cursor.fetchall()
    def save_project_cache(self,local_db_path,project,project_id,item,item_id):

        self.conn = self.create_connection(local_db_path, self.db_name)
        self.cursor = self.conn.cursor()
        self.create_table(self.conn, "Cache", project="VARCHAR(255)",project_id="INT(10)", item="VARCHAR(255)",item_id="INT(10)")
        self.insert_into(self.conn, "Cache", project=project, project_id=project_id,item=item,item_id=item_id)
        self.close_connection(self.conn)


    def get_last_deploy(self,local_db_path):
        if os.path.exists(local_db_path + self.db_name):
            self.conn = self.create_connection(local_db_path, self.db_name)
            self.cursor = self.conn.cursor()

            if not self.check_table_exists(self.conn, "Last_Deploy"):
                return False, []

            query = "SELECT `path`,`name`,`item_type`,`sha`,`path2`, FROM last_deploy;"

            self.cursor.execute(query)
            result = self.cursor.fetchall()
            self.close_connection(self.conn)
            return True,result
        else:
            return False, []

    def get_timestamp(self,local_db_path,**kwargs):
        if os.path.exists(local_db_path + self.db_name):
            self.conn = self.create_connection(local_db_path, self.db_name)
            self.cursor = self.conn.cursor()

            if not self.check_table_exists(self.conn, "Last_Deploy"):
                return None

            query = self.filtered_query("Last_Deploy",**kwargs)
            self.cursor.execute(query)
            result = self.cursor.fetchall()
            if not result:
                return None
            self.close_connection(self.conn)
            return result[0][-1],result[0][4]
        else:

            return None



    def save_last_deploy(self,local_db_path):
        self.conn = self.create_connection(local_db_path, self.db_name)
        self.cursor = self.conn.cursor()
        self.drop_table(self.conn, "last_deploy")
        query = "ALTER TABLE Current_Dir RENAME TO last_deploy;"
        self.cursor.execute(query)
        self.close_connection(self.conn)


    def save_current_dir(self,conn,data):
        self.conn = conn
        self.cursor = self.conn.cursor()
        self.drop_table(self.conn, "Current_Dir")
        self.create_table(self.conn, "Current_Dir", path="VARCHAR(255)", name="VARCHAR(255)",sha="VARCHAR(255)",path2="VARCHAR(255)")
        self.insert_into(self.conn, "Current_Dir", path=data[0], name=data[1],sha=data[2],path2=data[3])

    def compare(self,local_db_path):
        self.conn = self.create_connection(local_db_path, self.db_name)
        self.cursor = self.conn.cursor()
        if not self.check_table_exists(self.conn, "last_deploy"):
            query = "SELECT DISTINCT path2 FROM Current_Dir"
            self.cursor.execute(query)
            new = self.cursor.fetchall()
            return new,[],[]
        query = "SELECT DISTINCT path2 FROM Current_Dir WHERE path NOT IN (SELECT DISTINCT path FROM last_deploy)"
        self.cursor.execute(query)
        new = self.cursor.fetchall()
        query = "SELECT DISTINCT path2 FROM last_deploy WHERE path NOT IN (SELECT DISTINCT path FROM Current_Dir)"
        self.cursor.execute(query)
        delete = self.cursor.fetchall()
        query = "SELECT DISTINCT path2 FROM Current_Dir WHERE path IN (SELECT DISTINCT path FROM last_deploy) AND sha NOT IN (SELECT DISTINCT sha FROM last_deploy)"
        self.cursor.execute(query)
        change = self.cursor.fetchall()
        self.close_connection(self.conn)

        return new, change, delete

    def filtered_query(self,table_name,**filter):
        query = f'SELECT * FROM `{table_name}` '
        for index,(key,value) in enumerate(filter.items()):
            if index == 0:
                query += f"WHERE ({key}='{value}' "
            else:
                query += f"AND {key}='{value}' "
        query += ");"
        return query

    def create_table_query(self,table_name,**fields):
        query = f'CREATE TABLE IF NOT EXISTS `{table_name}` (id INTEGER PRIMARY KEY AUTOINCREMENT'
        for (key,value) in fields.items():
            query += f", {key} '{value}' "
        query += ");"
        return query

    def drop_table_query(self,table_name):
        return f"DROP TABLE IF EXISTS {table_name};"

    def insert_into_query(self,table_name,**fields):
        a = "INSERT INTO Token VALUES (Null,?,?);", ("124","test@test.com")
        "INSERT INTO table_name (column1, column2, column3, ...) VALUES (value1, value2, value3, ...);"

        parameters = []
        columns = "(id"
        values = "(Null"
        query = f'INSERT INTO `{table_name}`'


        for (key,value) in fields.items():
            parameters.append(value)
            columns += f",{key}"
            values += ",?"
        columns += ")"
        values += ");"

        query += columns + " VALUES " + values

        return query,tuple(parameters)

    def mkdirs(self,path):
        try:
            os.makedirs(path, exist_ok=True)
            return True
        except Exception as e:
            print(e)
            return False

    def rm_file(self,path):
        if os.path.exists(path):
            try:
                os.remove(path)
                return True
            except Exception as e:
                print(e)
                return False
        return False


import fnmatch
import os
import tarfile
import hashlib
from runflare.gitignore_parser import parse_gitignore
from runflare.runflare_client.data_manager.adapter import Adapter
from runflare.settings import FOLDER_NAME, TAR_NAME,DATASTORE,DEFAULT_IGNORE_FILE
from colorama import Style
from halo import Halo
from pathlib import Path
import copy


def makedirs(path):
    os.makedirs(path,exist_ok=True)


def clear():
    if os.name == "nt":
        os.system("cls")
    else:
        os.system("clear")

def get_current_path():
    return os.getcwd()

def get_text_hash(text):
    result = hashlib.sha1(text.encode())
    return result.hexdigest()

@Halo(text=Style.BRIGHT + "Scaning Directory", color="magenta")
def save_current_dir(root_path,file_exclude,folder_exclude):
    conn = Adapter.create_connection(root_path + f"/{FOLDER_NAME}/",DATASTORE.get("NAME"))
    Adapter.drop_table(conn,"Current_Dir")
    Adapter.create_table(conn,"Current_Dir", path="VARCHAR(255)",sha="VARCHAR(255)",path2="VARCHAR(255)")
    for path, subdirs, files in os.walk(root_path):
        subdirs[:] = [d for d in subdirs if d not in folder_exclude]

        for file in files:
            for e in file_exclude:
                if fnmatch.fnmatch(file, e):
                    continue
            file_path = os.path.join(path, file).replace(root_path, ".")
            abs_file_path = os.path.join(path, file)

            status = os.stat(abs_file_path)
            Adapter.insert_into(conn,"Current_Dir",path=file_path, sha=get_text_hash(str(abs_file_path) + str(status.st_size) + str(status.st_ctime) + str(status.st_mtime)), path2=file_path.replace(".\\", "").replace("\\", "/"))

    file_number = Adapter.execute(conn,'SELECT Count(*) FROM Current_Dir;')
    Adapter.close_connection(conn)
    return file_number[0][0]

def compare(project_root):
    file_exclude, folder_exclude = get_ignore(project_root)
    file_number = save_current_dir(project_root,file_exclude, folder_exclude)
    new,change,delete = Adapter.compare(project_root + f"/{FOLDER_NAME}/")
    relative_path = os.path.relpath(project_root, ".")
    matches = parse_gitignore('.gitignore', base_dir=relative_path)
    tmp = copy.copy(delete)
    for e in file_exclude:
        for item in delete:
            if fnmatch.fnmatch(item[0], e):
                tmp.remove(item)
    return new,change,tmp,file_number


def make_tar(project_root,changed, new):
    with tarfile.open(project_root + f"/{FOLDER_NAME}/{TAR_NAME}", "w:gz") as tar:
        os.chdir(project_root)
        for name in changed:
            tar.add(name[0])
        for item in new:
            tar.add(item[0])

def list_to_dict(data):
    lst = []
    for item in data:
        lst.append({
            "path2": item[0],
        })
    return lst

def command_help(command, **kwargs):
    for key, value in kwargs.items():
        clear()
        print("runflare {} <option>\n\nOPTIONS".format(command))
        print("\t-{},--{} \t\t {}".format(key, key, value))

def stripn(n):
    n = n.strip("\n")
    if not n.startswith("#"):
        return n

def ignore_parser(ig_list):
    lst = set(map(stripn,ig_list))
    file = []
    folder = []
    for i in lst:
        if i:
            if i.endswith("/"):
                if not "*" in i:
                    folder.append(i.rstrip("/"))
            else:
                file.append(i)
    return file,folder

def get_ignore(project_root):
    if not os.path.exists(project_root + "/.gitignore"):
        full_path = str(Path(__file__).resolve().parent / ".runflare_ignore")
    else:
        full_path = project_root + "/.gitignore"
        with open(full_path, "r+") as default_ignored:
            lst = list(map(lambda x: x.strip("\n"),default_ignored.readlines()))
            for item in DEFAULT_IGNORE_FILE:
                if item not in lst:
                    default_ignored.write(f"{item}\n")

    with open(full_path) as ignored:
        ig = ignored.readlines()

    return ignore_parser(ig)


import json
import os
from time import sleep
from runflare.runflare_client.data_manager.adapter import Adapter
from runflare.runflare_client.service.projects import get_projects, get_project_items
from colorama import Fore, Style,init
from runflare.utils import clear, compare, make_tar, list_to_dict,makedirs
from .cache import Cache_Manager
from .upload import upload, pre_upload_check, uploader_info

from ...settings import FOLDER_NAME, TAR_NAME, CHANGES_NAME, MAX_TRY


def deploy(y):
    project_root = Adapter.get_project_root()
    clear()
    cache_object = Cache_Manager(project_root, type="Deploy")
    data = cache_object.cache(y)
    selected_project, selected_service, selected_service_id = data[1],data[2],data[3]

    try_num = 1
    while try_num <= MAX_TRY:
        clear()
        print(Style.BRIGHT + f"Uploading Try ({try_num}/{MAX_TRY})")
        status, response = uploader_info(selected_service_id)
        if status:
            break
        try_num += 1
        sleep(2)
    if not status:
        return Fore.RED + response

    url = response.json().get("url")
    token = response.json().get("token")


    status, response = pre_upload_check(url,token)
    if not status:
        return Fore.RED + response
    clear()
    print(f"Scaning {project_root} ...")
    new, changed, deleted,scaned_files = compare(project_root)
    print(Fore.GREEN + Style.BRIGHT + "Scan Finished")
    if not new and not deleted and not changed:
        print(Fore.RED + "No New Files\nDirectory already synced with server !")
        exit()

    makedirs(project_root + f"/{FOLDER_NAME}/")
    with open(project_root + f"/{FOLDER_NAME}/{CHANGES_NAME}", "w+") as changes:
        changes.write(json.dumps({
            "new": list_to_dict(new),
            "modify": list_to_dict(changed),
            "delete": list_to_dict(deleted)
        }, indent=4))


    print(Style.BRIGHT + "Start Compressing")
    make_tar(project_root,changed, new)
    print(Fore.GREEN + Style.BRIGHT + "Compressing Finished")

    size = os.path.getsize(project_root + f"/{FOLDER_NAME}/{TAR_NAME}") / 1048576
    status, response = upload(project_root,url,token)
    if status:
        Adapter.save_last_deploy(project_root + f"/{FOLDER_NAME}/")
        os.remove(project_root + f"/{FOLDER_NAME}/{TAR_NAME}")
        os.remove(project_root + f"/{FOLDER_NAME}/{CHANGES_NAME}")
        result = "\n\n {}Files Successfully Uploaded {:.3f} MB".format(Fore.GREEN + Style.BRIGHT, size)
        result += "\n\n  Scaned Files :{} \n   {}New Files :{} \n   Changed Files :{} \n   Deleted Files :{}".format(scaned_files,Fore.GREEN,len(new),len(changed),len(deleted))
        result += "\nDeployment takes time, watch log with runflare log -f -y".format(Fore.GREEN)
        return result

    else:
        return Fore.RED + response





from colorama import init, Fore
init()


class RunflareException(Exception):
    pass



class Unauthorized_Exception(RunflareException):

    def __str__(self):
        return Fore.RED + "You'r Not Logged in"

class Server_Exception(RunflareException):
    pass


class Message_Exception(RunflareException):

    def __init__(self,message,status):
        super().__init__()
        self.__message = message
        self.__status = status

    def __str__(self):
        return "{status} {message}".format(status=self.__status, message=self.__message)



class Unknown_Exception():
    def __str__(self):
        return Fore.RED + "You'r Unknown_Exception"


import platform
from pathlib import Path


BASE_URL = "https://dash.runflare.com"
WEBSOCKET_URL = 'wss://dash.runflare.com'
FOLDER_NAME = ".cloud"
DATASTORE = {
    "BACKEND": "sqlite3",
    "NAME": "db.sqlite3",
}
TAR_NAME = "workspace.tar.gz"
CHANGES_NAME = "changes.json"

LOGIN_URL = '/account/login/'
PROJECT_LIST_URL = '/project/'
ITEM_LIST_URL = '/project/items-show/{}/'
UPLOAD_URL = "/project/deploy/{}/"
START_URL = "/project/deployment-start/{}/"
STOP_URL = "/project/deployment-stop/{}/"
RESTART_URL = "/project/deployment-restart/{}/"
VERSION_URL = "/version/"


NR_LOG_URL = "/project/pod-log/{}/"
NR_EVENTS_URL = '/project/events/{}/'

MAX_TRY = 3

LOG_URL = "pod-log"
EVENTS_URL = "project-events"


OS_SYSTEM = platform.system()
OS_RELEASE = platform.release()
OS_VERSION = platform.version()
OS_PLATFORM = platform.platform()
USER_HOME_PATH = Path.home()

BASE_DIR = Path(__file__)

DEFAULT_IGNORE_FILE = ['/.cloud','/.cloud/','.cloud/']




import asyncio
import json
import time
import ssl
from colorama import init, Fore,Style
import websockets
from runflare.settings import WEBSOCKET_URL
from runflare.runflare_client.data_manager.adapter import Adapter
from runflare.utils import clear
class Socket:

    async def watch(self,url,id):
        clear()
        print(Style.BRIGHT + "Intialize Secure Session")
        url = WEBSOCKET_URL + "/ws/{}/{}/?token={}".format(url,id, self._get_token())
        try:
            ssl_context = ssl.SSLContext()
            ssl_context.verify_mode = ssl.CERT_NONE
            # ssl_context.check_hostname = False
            async with websockets.connect(url,ssl=ssl_context) as ws:
                print(Fore.GREEN + Style.BRIGHT + "Connected")
                # while ws.wait_closed():
                while True:
                    msg = await ws.recv()
                    print(msg)
                    # msg = json.loads(msg)
                    # message = msg["message"]
                    # error = msg["error"]
                    # output = "{}".format(message)
                    # if output != "" and not error:
                    #     print(Style.BRIGHT + output.rstrip("\n"))
                    # elif error == 1:
                    #     print(Fore.RED + Style.BRIGHT + message.rstrip("\n"))
                    #     exit()
                    # elif error == 2:
                    #     print(Fore.RED + Style.BRIGHT + message.rstrip("\n"))
        except Exception as e:
            print(Fore.BLUE + "-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_")
            print(Fore.RED + Style.BRIGHT + "Error On Connecting")
            print(Fore.RED + Style.BRIGHT + str(e))
            print(Fore.RED + Style.BRIGHT + "Send Ticket To Runflare Support")
            exit()


    async def interactive(self, url,id):
        print(Style.BRIGHT + "Intialize Secure Session")
        url = WEBSOCKET_URL + "/ws/{}/{}/?token={}".format(url,id, self._get_token())
        try:
            ssl_context = ssl.SSLContext()
            ssl_context.verify_mode = ssl.CERT_NONE
            print(url)
            async with websockets.connect(url,ssl=ssl_context) as ws:
                print(Fore.GREEN + Style.BRIGHT + "Connected")
                print(Fore.BLUE + Style.BRIGHT + "Enter exit or exit() to quit")
                await ws.send("pwd")
                pwd = (json.loads(await ws.recv())["message"]).rstrip("\n")
                while ws.wait_closed:
                    inp = input(f"[{pwd}]# ")
                    if inp.lower() == "exit()" or inp.lower() == "exit":
                        print()
                        print(Fore.BLUE + "-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_")
                        print(Style.BRIGHT + "EXIT, CODE 0")
                        print(Style.BRIGHT + "more help on runflare --help")
                        exit()
                    await ws.send(inp)
                    rc = await ws.recv()
                    rc = json.loads(rc)
                    message = rc["message"]
                    error = rc["error"]
                    output = "{}".format(message)
                    if output != "" and not error:
                        print(Style.BRIGHT + output.rstrip("\n"))
                    elif error == 1:
                        print(Fore.RED + Style.BRIGHT + message.rstrip("\n"))
                        exit()
                    elif error == 2:
                        print(Fore.RED + Style.BRIGHT + message.rstrip("\n"))
                    await ws.send("pwd")
                    pwd = (json.loads(await ws.recv())["message"]).rstrip("\n")
        except Exception as e:
            print(Fore.BLUE + "-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_")
            print(Fore.RED + Style.BRIGHT + "Error On Connecting")
            print(Fore.RED + Style.BRIGHT + str(e))
            print(Fore.RED + Style.BRIGHT + "Send Ticket To Runflare Support")
            exit()

    def run_loop(self,type,url,id):
        try:
            if type == "watch":
                print(id)
                asyncio.get_event_loop().run_until_complete(self.watch(url,id))
            elif type == "interactive":
                asyncio.get_event_loop().run_until_complete(self.interactive(url, id))

        except KeyboardInterrupt:
            print()
            print(Fore.BLUE + "-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_")
            print(Style.BRIGHT + "EXIT, CODE 0")
            print(Style.BRIGHT + "more help on runflare --help")
            exit()


    def _get_token(self):
        status, message = Adapter.get_token()
        if status:
            return message
        return None


from runflare.runflare_client.requester import Requester
from runflare.settings import PROJECT_LIST_URL,ITEM_LIST_URL
from colorama import Fore, Style
from halo import Halo


@Halo(text=Style.BRIGHT + "Getting Projects List...", color="magenta")
def get_projects():
    request = Requester("GET", PROJECT_LIST_URL)
    return request.get_response


@Halo(text=Style.BRIGHT + "Getting Item List...", color="magenta")
def get_project_items(project_id):
    request = Requester("GET", ITEM_LIST_URL.format(project_id))
    return request.get_response



from runflare.runflare_client.data_manager.adapter import Adapter

from runflare.runflare_client.requester import Requester
from runflare.settings import UPLOAD_URL, FOLDER_NAME, TAR_NAME, CHANGES_NAME
from requests_toolbelt.multipart import encoder
from colorama import Style
from halo import Halo


@Halo(text=Style.BRIGHT + "Uploading Files To Server...", color="magenta")
def upload(project_root,url,token):
    with open(project_root + f"/{FOLDER_NAME}/{TAR_NAME}", 'rb') as tar_file:
        with open(project_root + f"/{FOLDER_NAME}/{CHANGES_NAME}", 'rb') as change:
            form = encoder.MultipartEncoder({
                'files': ('workspace.tar', tar_file, "application/octet-stream"),
                'changes': (CHANGES_NAME, change,'application/json'),
            })

            request = Requester("POST", url, data=form,abs=True,headers={"Content-Type": form.content_type,'token':token})

    return request.get_response

def uploader_info(item_id):
    request = Requester("POST", UPLOAD_URL.format(item_id))
    return request.get_response

def pre_upload_check(url,token):
    request = Requester("GET", url, headers={'token':token},abs=True)
    return request.get_response


from runflare.runflare_client.service.projects import get_projects,get_project_items
from runflare.runflare_client.service.manage import start,stop,restart

__all__ = ['get_projects',"get_project_items","start","restart",'stop']


from PyInquirer import prompt,style_from_dict,Token
from runflare.utils import clear
from runflare.runflare_client.requester import Requester
from runflare.settings import LOGIN_URL
from runflare.runflare_client.data_manager.adapter import Adapter

from colorama import Fore, Style


def save_token():
    clear()
    credentials = [
        {
            'type': 'input',
            'name': 'email',
            'message': 'Please enter your email > ',

        },
        {
            'type': 'password',
            'name': 'password',
            'message': 'Please enter your password > ',

        },
    ]

    credentials = prompt(credentials)
    email = credentials['email']
    password = credentials['password']
    data = {'email': email, 'password': password}

    request = Requester("POST",LOGIN_URL,data=data)
    status,response = request.get_response
    if status:
        token = response.json().get("token",None)
        Adapter.save_token(token=token, email=email)
        return Fore.GREEN + " Successfully Logged In"
    else:
        return Fore.RED + " Wrong Credentials"

def del_token():
    clear()
    questions = [
        {
            'type': 'confirm',
            'name': 'exit',
            'message': 'Do you want to exit?',
            'default': True,
        }]
    questions = prompt(questions)
    answer = questions['exit']
    if answer:
        status, message = Adapter.del_token()
        if status:
            return Fore.GREEN + message
        return Fore.RED + message
    else:
        return Fore.RED + "Choose Carefully"
